pygeodesy.booleans._BooleanBase

Package pygeodesy :: Module booleans :: Class _BooleanBase |
[frames] | no frames]

# Class _BooleanBase

    object --+
             |
            _BooleanBase

Known Subclasses:
  - BooleanFHP
  - , BooleanGH

Instance Methods
__add__(self, other) Sum: `this + other` clips. |
__and__(self, other) Intersection: `this & other`. |
__iadd__(self, other) In-place sum: `this += other` clips. |
__iand__(self, other) In-place intersection: `this &= other`. |
__ior__(self, other) In-place union: `this |= other`. |
__or__(self, other) Union: `this | other`. |
__radd__(self, other) Reverse sum: `other + this` clips. |
__rand__(self, other) Reverse intersection: `other & this` |
__ror__(self, other) Reverse union: `other | this` |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`